# Py SPW
Library fo work with SPworlds API.

## Installation
Library written on 3.10.5

To install, run this command:
`pip install Py-Spw`

After import Py-SPW to your project: `import pyspw`

## Links
- [PyPi](https://pypi.org/project/Py-SPW)
- [Documentation](https://github.com/teleport2/Py-SPW/wiki)
- [Author](https://github.com/teleport2)